@@ -26,7 +26,7 @@ from winrm.exceptions import WinRMOperationTimeoutError
 from winrm.protocol import Protocol
 
 from airflow.exceptions import AirflowException
-from airflow.providers.microsoft.winrm.version_compat import BaseHook
+from airflow.providers.common.compat.sdk import BaseHook
 from airflow.utils.platform import getuser
 
 # TODO: FIXME please - I have too complex implementation
@@ -286,3 +286,12 @@ class WinRMHook(BaseHook):
             raise AirflowException(f"WinRM operator error: {e}")
         finally:
             winrm_client.close_shell(shell_id)
+
+    def test_connection(self):
+        try:
+            (r_code, std_out, std_err) = self.run("cd")
+            if r_code != 0:
+                raise RuntimeError(std_err)
+            return True, "Connection successful."
+        except Exception as e:
+            return False, str(e)
